import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import '../flutter_icu_common.dart';

/// 图片加载（支持本地与网络图片）
class ICULoadImage extends StatelessWidget {
  const ICULoadImage(this.image,
      {Key key,
      this.width,
      this.height,
      this.fit: BoxFit.cover,
      this.format: "png",
      this.holderImg: "images/none"})
      : super(key: key);

  final String image;
  final double width;
  final double height;
  final BoxFit fit;
  final String format;
  final String holderImg;

  @override
  Widget build(BuildContext context) {
    if (TextUtil.isEmpty(image) || image == "null") {
      return ICULoadAssetImage(
        holderImg,
        height: height,
        width: width,
        fit: fit,
        format: format,
      );
    } else {
      if (image.startsWith("http")) {
        return CachedNetworkImage(
          imageUrl: image,
          placeholder: (context, url) {
            return ICULoadAssetImage(holderImg,
                height: height, width: width, fit: fit);
          },
          errorWidget: (context, url, error) {
            return ICULoadAssetImage(holderImg,
                height: height, width: width, fit: fit);
          },
          width: width,
          height: height,
          fit: fit,
        );
      } else {
        return ICULoadAssetImage(
          image,
          height: height,
          width: width,
          fit: fit,
          format: format,
        );
      }
    }
  }
}

/// 加载本地资源图片
class ICULoadAssetImage extends StatelessWidget {
  const ICULoadAssetImage(this.image,
      {Key key,
      this.width,
      this.height,
      this.fit,
      this.format: 'png',
      this.color})
      : super(key: key);

  final String image;
  final double width;
  final double height;
  final BoxFit fit;
  final String format;
  final Color color;

  @override
  Widget build(BuildContext context) {
    return Image.asset(
      ICUImageUtils.getImgPath(image, format: format),
      height: height,
      width: width,
      fit: fit,
      color: color,
    );
  }
}
